@@ -1,6 +1,6 @@
 # Utilities to twinkle default mail message
 
-;# $Id: mail.pl 1 2006-08-24 13:24:12Z rmanfredi $
+;# $Id: mail.pl 38 2008-06-13 09:32:24Z rmanfredi $
 ;#
 ;#  Copyright (c) 1990-2006, Raphael Manfredi
 ;#  
@@ -76,8 +76,10 @@ sub add_body {
 
 # Copy mail in out/
 sub cp_mail {
+	my ($file) = @_;
+	$file = "../mail" unless defined $file;
 	local($_);
-	open(MAIL, '../mail');
+	open(MAIL, $file)	|| die "Can't open $file: $!";
 	open(HERE, '>mail');
 	print HERE while <MAIL>;
 	close MAIL;
